@@ -129,11 +129,12 @@ class SummaryView(SwaggerView):
         get summary of tasks
         """
 
-        queue = dqueue.core.Queue(request.args.get('queue', 'default'))
+        queue_name = request.args.get('queue', 'default')
+        queue = dqueue.core.Queue(queue_name)
 
         tasks = queue.summary
 
-        logger.info("got summary: %s", tasks)
+        logger.info("got summary: %s for %s", tasks, queue_name)
 
         return jsonify(
                 tasks=tasks
@@ -216,6 +217,12 @@ class WorkerOffer(SwaggerView):
                     'required': False,
                     'type': 'number',
                 },
+                {
+                    'name': 'worker_knowledge_json',
+                    'in': 'query',
+                    'required': False,
+                    'type': 'string',
+                },
             ]
 
     responses = {
@@ -230,10 +237,16 @@ class WorkerOffer(SwaggerView):
 
     def get(self, worker_id):
         update_expected_in_s = request.args.get('update_expected_in_s', -1, type=float)
+
+        worker_knowledge = json.loads(request.args.get('worker_knowledge_json', '{}'))
+
+        if worker_knowledge == {}:
+            worker_knowledge = None
+
         queue = dqueue.core.Queue(request.args.get('queue', 'default'), worker_id=worker_id)
 
         try:
-            task = queue.get(update_expected_in_s)
+            task = queue.get(update_expected_in_s, worker_knowledge=worker_knowledge)
             logger.warning("got task: %s", task)
             return jsonify(
                     task.as_dict,
@@ -735,6 +748,12 @@ class ClearLog(SwaggerView):
                     'type': 'string',
                     'enum': ['worker', 'task'],
                 },
+                {
+                    'name': 'leave_last',
+                    'in': 'query',
+                    'required': False,
+                    'type': 'number',
+                },
             ]
 
     responses = {
@@ -748,7 +767,8 @@ class ClearLog(SwaggerView):
         queue = dqueue.core.Queue()
 
         r = queue.clear_event_log(request.args.get('only_older_than_days', None, type=float),
-                                  request.args.get('only_kind', None, type=str))
+                                  request.args.get('only_kind', None, type=str),
+                                  request.args.get('leave_last', None, type=int))
 
         logger.info("clear_log api clears %d entries", r)
 
@@ -929,12 +949,19 @@ class WorkerQuestion(SwaggerView):
 
         print("got:", worker_id, task_data)
 
-        task_entry = queue.put(task_data, submission_data=submission_data)
+        try:
+            task_entry = queue.put(task_data, submission_data=submission_data)
+            logger.warning("questioned task: %s", task_entry)
+            return jsonify(
+                        task_entry
+                    )
+        except Exception as e:
+            r = jsonify(
+                        {"exception": "unable to insert"}
+                    )
+            r.status_code = 400
+            return r
 
-        logger.warning("questioned task: %s", task_entry)
-        return jsonify(
-                    task_entry
-                )
 
 app.add_url_rule(
      '/worker/question',
