@@ -55,15 +55,13 @@ def version(obj, validate):
 @click.pass_obj
 def auth(obj):
     print(core.__version__)
+    print("my auth level: ADMIN")
 
 
 def log_info(queue):
     for q in queue.list_queues(None):
-        logger.info(colored(q, 'green'))
-        logger.info("; ".join(
-                f"{k}: {v}" for k,v in q.summary.items()
-            ))
-        logger.info("\n")
+        print(f"\033[37m{q}\033[0m")
+        print(f"\033[1;31m{'live facts':>20s}: \033[0m\033[1;36m", "; ".join(f"{k}: {v}" for k,v in q.summary.items()), "\033[0m")
 
 @cli.command()
 @click.pass_obj
@@ -92,11 +90,31 @@ def console_size():
 @click.option("-d", "--debug", default=False, is_flag=True)
 @click.option("-l", "--log", default=False, is_flag=True)
 @click.option("-i", "--info", default=False, is_flag=True)
-@click.option("-s", "--state", default=None)
+@click.option("-s", "--select", default=None)
+@click.option("-j", "--json-output", default=None)
 #@click.option("-a", "--max-age", default=None)
 @click.pass_obj
-def list(obj, debug, log, info, state):
+def list(obj, debug, log, info, select, json_output):
+    state = None
+    select_task = None
+
+    j_f = None
+    if json_output:
+        j_f = open(json_output, "wt")
+
+
+    if select is not None:
+        selector, selection = select.split(":")
+
+        if selector == "state":
+            state = selection
+        elif selector == "task":
+            select_task = selection
+
     for task in obj['queue'].list_tasks(state=state):
+        if select_task is not None:
+            if task['key'] != select_task:
+                continue
 
         td = task['task_dict']['task_data']
 
@@ -135,6 +153,9 @@ def list(obj, debug, log, info, state):
             t = Task.from_task_dict(task['task_dict'])
             print("Task: ", t)
             print("Task key: ", t.key)
+        
+        if j_f is not None:
+            json.dump(task['task_dict'], j_f)
 
         if log:
             for l in obj['queue'].view_log(task['key'])['event_log']:
@@ -236,14 +257,11 @@ def view(obj, follow, since=0):
                 till_next_info = info_cadence
 
         if time.time() - last_info_time > 5:
-            print()
+
             log_info(obj['queue'])
 
-            for q in obj['queue'].list_queues(None):
-                print("\033[34m", "; ".join(f"{k}: {v}" for k,v in obj['queue'].summary.items()), "\033[0m")
-
             recent_workers = [k for k,v in active_workers.items() if v>time.time()-30 and not k.startswith('oda-dqueue-')]
-            print(f"\033[35m{len(recent_workers)} recent workers\033[0m: {', '.join(recent_workers)}")
+            print(f"\033[1;31m{len(recent_workers):>5d} recent workers:\033[0m \033[1;35m{', '.join(recent_workers)}\033[0m")
 
             last_info_time = time.time()
 
@@ -322,14 +340,14 @@ def guardian(obj, watch):
         print(colored("forgiven:", "green"), task_data)
         
         #clear event log 
-        N = obj['queue'].clear_event_log(only_older_than_days=2./24.)
+        N = obj['queue'].clear_event_log(leave_last=100)
+        #N = obj['queue'].clear_event_log(only_older_than_days=2./24.)
         print(f"cleared event log of {N} entries")
 
         # stats
 
         print("getting queue statistics...")
-        for k,v in obj['queue'].summary.items():
-            print(k, ":", v, end="; ")
+        log_info(obj['queue'])
         print("\n")
 
         print("sleeping", watch)
